@@ -15,9 +15,20 @@ log = logging.getLogger(__name__)
 here = os.path.dirname(__file__)
 base = os.path.join(here, "data")
 
+db = None
+
+def __init__(app):
+    app.register("wiki/(.*?).html", index)
+    print "Startup", db, here
+    db = "Test"
+
+def __del__(app):
+    print "Shutdown", db, here
+    db = None
+
 @controller
 def index():
-    c.isgae =  "google.appengine" in sys.modules
+    c.isgae = "google.appengine" in sys.modules
     c.ispaster = not c.isgae
     c.pyxerversion = pyxer.__version__
     c.modules = sys.modules
@@ -32,6 +43,6 @@ def index():
                     name + "/",
                     f.read().strip()))
                 f.close()
-                log.debug("Added sample %r", c.samples[-1])
+                log.debug("Added sample %r", c.samples[ - 1])
         except:
             log.exception("Error while collecting samples")
